@@ -780,8 +780,10 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
         // Inspired by fuse-zip source code: fuse-zip/lib/fileNode.cpp
         switch (opsys) {
         case ZIP_OPSYS_UNIX:
-            // Unix permissions are stored in the leftmost 16 bits of the external file attribute.
-            file.setPermissions(KIO::convertPermissions(attributes >> 16));
+            if (attributes != 0) {
+                // Unix permissions are stored in the leftmost 16 bits of the external file attribute.
+                file.setPermissions(KIO::convertPermissions(attributes >> 16));
+            }
             break;
         default:    // TODO: non-UNIX.
             break;
@@ -963,52 +965,6 @@ bool LibzipPlugin::copyFiles(const QVector<Archive::Entry*> &files, Archive::Ent
     return true;
 }
 
-QString LibzipPlugin::permissionsToString(mode_t perm)
-{
-    QString modeval;
-    if ((perm & S_IFMT) == S_IFDIR) {
-        modeval.append(QLatin1Char('d'));
-    } else if ((perm & S_IFMT) == S_IFLNK) {
-        modeval.append(QLatin1Char('l'));
-    } else {
-        modeval.append(QLatin1Char('-'));
-    }
-    modeval.append((perm & S_IRUSR) ? QLatin1Char('r') : QLatin1Char('-'));
-    modeval.append((perm & S_IWUSR) ? QLatin1Char('w') : QLatin1Char('-'));
-    if ((perm & S_ISUID) && (perm & S_IXUSR)) {
-        modeval.append(QLatin1Char('s'));
-    } else if ((perm & S_ISUID)) {
-        modeval.append(QLatin1Char('S'));
-    } else if ((perm & S_IXUSR)) {
-        modeval.append(QLatin1Char('x'));
-    } else {
-        modeval.append(QLatin1Char('-'));
-    }
-    modeval.append((perm & S_IRGRP) ? QLatin1Char('r') : QLatin1Char('-'));
-    modeval.append((perm & S_IWGRP) ? QLatin1Char('w') : QLatin1Char('-'));
-    if ((perm & S_ISGID) && (perm & S_IXGRP)) {
-        modeval.append(QLatin1Char('s'));
-    } else if ((perm & S_ISGID)) {
-        modeval.append(QLatin1Char('S'));
-    } else if ((perm & S_IXGRP)) {
-        modeval.append(QLatin1Char('x'));
-    } else {
-        modeval.append(QLatin1Char('-'));
-    }
-    modeval.append((perm & S_IROTH) ? QLatin1Char('r') : QLatin1Char('-'));
-    modeval.append((perm & S_IWOTH) ? QLatin1Char('w') : QLatin1Char('-'));
-    if ((perm & S_ISVTX) && (perm & S_IXOTH)) {
-        modeval.append(QLatin1Char('t'));
-    } else if ((perm & S_ISVTX)) {
-        modeval.append(QLatin1Char('T'));
-    } else if ((perm & S_IXOTH)) {
-        modeval.append(QLatin1Char('x'));
-    } else {
-        modeval.append(QLatin1Char('-'));
-    }
-    return modeval;
-}
-
 QString LibzipPlugin::fromUnixSeparator(const QString& path)
 {
     if (!m_backslashedZip) {
